@@ -1,5 +1,5 @@
 """OSEF private types definition."""
-__version__ = "1.2.1"
+__version__ = "1.3.0"
 
 # Standard imports
 from enum import Enum, IntEnum
@@ -69,7 +69,7 @@ class OsefTypes(IntEnum):
     ZONE_VERTICAL_LIMITS = 56
     GEOGRAPHIC_POSE_PRECISE = 57
     _ROAD_MARKINGS_BITS = 58
-    FILTERED_POSE = 59
+    _SMOOTHED_POSE = 59
     _INTERACTIVE_REQUEST = 60
     _INTERACTIVE_RESPONSE = 61
     _INTERACTIVE_REQUEST_ID = 62
@@ -91,23 +91,23 @@ class OsefKeys(Enum):
     optional, which describe its position, physical property, movement, etc...
     Contains following sub-TLVs:
     - exactly one:     Number of Points               (NUMBER_OF_POINTS)
-    - exactly one:     Number of layers               (NUMBER_OF_LAYERS)
+    - exactly one:     Number of Layers               (NUMBER_OF_LAYERS)
     - none or one:     Spherical Coordinates          (SPHERICAL_COORDINATES) [DEPRECATED USAGE]
     - none or one:     Reflectivities                 (REFLECTIVITIES)
     - none or one:     Background Flags               (BACKGROUND_FLAGS) [DEPRECATED USAGE]
-    - none or one:     Cartesian coordinates          (CARTESIAN_COORDINATES)
+    - none or one:     Cartesian Coordinates          (CARTESIAN_COORDINATES)
     - none or one:     BGR Colors                     (BGR_COLORS)
     - none or one:     Azimuths Column                (AZIMUTHS_COLUMN)
     - none or one:     Cloud Processing               (CLOUD_PROCESSING)
     - none or one:     Percept                        (PERCEPT)
-    - none or one:     Object Id 32 bits              (OBJECT_ID_32_BITS)
+    - none or one:     Object ID 32 Bits              (OBJECT_ID_32_BITS)
     - none or one:     Cartesian Coordinates 4F       (CARTESIAN_COORDINATES_4F) [DEPRECATED USAGE]
-    - none or one:     Background bits                (BACKGROUND_BITS)
-    - none or one:     Ground plane bits              (GROUND_PLANE_BITS)
+    - none or one:     Background Bits                (BACKGROUND_BITS)
+    - none or one:     Ground Plane Bits              (GROUND_PLANE_BITS)
     - none or one:     Azimuths                       (AZIMUTHS)
     - none or one:     Elevations                     (ELEVATIONS)
     - none or one:     Distances                      (DISTANCES)
-    - none or one:     Road Markings bits             (ROAD_MARKINGS_BITS)
+    - none or one:     Road Markings Bits             (ROAD_MARKINGS_BITS)
     """
     AUGMENTED_CLOUD = "augmented_cloud"
 
@@ -151,7 +151,7 @@ class OsefKeys(Enum):
     BACKGROUND_FLAGS = "background_flags"
 
     """
-    Cartesian coordinates
+    Cartesian Coordinates
     **Output when**: Augmented Cloud is enabled.
     Contains list of Cartesian single-precision float coordinates, three per point:
     * x : meters, range [ -inf .. +inf ]
@@ -159,7 +159,7 @@ class OsefKeys(Enum):
     * z : meters, range [ -inf .. +inf ]
     **Coordinate Frame**:
     - Passthrough & Mobile: Relative to LiDAR Coordinate Frame.
-    - Static: in Absolute/World Frame, witch is:
+    - Static: in Absolute/World Frame, which is:
         - Single-LiDAR: On-Ground LiDAR Coordinate Frame.
         - Multi-LiDARs: Map Coordinate Frame.
     """
@@ -232,7 +232,7 @@ class OsefKeys(Enum):
     _AZIMUTHS_COLUMN = "azimuths_column"
 
     """
-    Number of layers
+    Number of Layers
     **Output when**: Augmented Cloud is enabled.
     **Format**: Contains 32 bits unsigned int value.
     **Purpose**: Represents the number of layers of the point cloud.
@@ -269,23 +269,8 @@ class OsefKeys(Enum):
     """
     Class ID Array
     **Output when**: Tracking is enabled.
-    **Format**: list of signed 32 bits integers.
+    **Format**: list of signed 32 bits integers, using enum CLASS ID.
     **Purpose**: Contains list of class IDs.
-    Mapping between ID and class is given below:
-    * 0: UNKNOWN (class cannot yet be determined with confidence)
-    * 1: PERSON
-    * 2: LUGGAGE
-    * 3: TROLLEY
-    * 4: TRUCK
-    * 5: BUS
-    * 6: CAR
-    * 7: VAN
-    * 8: TWO_WHEELER
-    * 9: MASK
-    * 10: NO_MASK
-    * 11: LANDMARK
-    Note that this is an extended list, covering all possible class IDs.
-    The effective list of detected classes is always a subset, adapted to the use cases of the version.
     """
     CLASS_ID_ARRAY = "class_id_array"
 
@@ -297,7 +282,7 @@ class OsefKeys(Enum):
     _CONFIDENCE_ARRAY = "confidence_array"
 
     """
-    Timestamped data
+    Timestamped Data
     **Output when**: Always.
     Contains following sub-TLVs:
     - exactly one:     Timestamp Microsecond          (TIMESTAMP_MICROSECOND)
@@ -309,18 +294,7 @@ class OsefKeys(Enum):
 
     """
     Percept
-    Contains list of percept classes represented as unsigned 16-bits integer.
-    * 0: DEFAULT
-    * 1: ROAD
-    * 2: VEGETATION
-    * 3: GROUND
-    * 4: SIGN
-    * 5: BUILDING
-    * 6: FLAT_GND
-    * 7: UNKNOWN
-    * 8: MARKING
-    * 9: OBJECT
-    * 10: WALL
+    Contains list of percept classes represented as unsigned 16-bits integer, using enum PERCEPT ID.
     """
     _PERCEPT = "percept"
 
@@ -334,7 +308,7 @@ class OsefKeys(Enum):
 
     """
     Pose
-    **Output when**: Ego-Motion is enabled.
+    **Output when**: Slam is enabled.
     **Purpose**: Pose of the LiDAR.
     **Format**: Concatenation of 12 floats of 32-bits each, in this order:
     - Tx, Ty and Tz, representing the translation vector T to get the position coordinates in meters
@@ -355,7 +329,7 @@ class OsefKeys(Enum):
         [Tz]
     ```
     **Coordinate Frame**:
-    Absolute/World Frame, witch is:
+    Absolute/World Frame, which is:
     - Ego-Motion: Initial pose of the LiDAR.
     - Relocalisation: Map Coordinate Frame.
     """
@@ -367,14 +341,14 @@ class OsefKeys(Enum):
     Contains following sub-TLVs:
     - none or one:     Augmented Cloud                (AUGMENTED_CLOUD)
     - none or one:     Pose                           (POSE)
-    - none or one:     Geographic pose                (GEOGRAPHIC_POSE)
-    - none or one:     Geographic pose precise        (GEOGRAPHIC_POSE_PRECISE)
+    - none or one:     Geographic Pose                (GEOGRAPHIC_POSE)
+    - none or one:     Geographic Pose Precise        (GEOGRAPHIC_POSE_PRECISE)
     - none or one:     Ego Motion                     (EGO_MOTION)
     - none or one:     Tracked Objects                (TRACKED_OBJECTS)
     - none or one:     Zones Def                      (ZONES_DEF)
     - none or one:     Zones Objects Binding          (ZONES_OBJECTS_BINDING) [DEPRECATED USAGE]
-    - none or one:     Zones Objects Binding 32 bits  (ZONES_OBJECTS_BINDING_32_BITS)
-    - none or one:     Filtered Pose                  (FILTERED_POSE)
+    - none or one:     Zones Objects Binding 32 Bits  (ZONES_OBJECTS_BINDING_32_BITS)
+    - none or one:     Smoothed Pose                  (SMOOTHED_POSE)
     """
     SCAN_FRAME = "scan_frame"
 
@@ -384,7 +358,7 @@ class OsefKeys(Enum):
     **Purpose**: Properties of tracked objects, which includes centroid, bbox, speed...
     Contains following sub-TLVs:
     - exactly one:     Number of Objects              (NUMBER_OF_OBJECTS)
-    - exactly one:     Object Id 32 bits              (OBJECT_ID_32_BITS)
+    - exactly one:     Object ID 32 Bits              (OBJECT_ID_32_BITS)
     - none or one:     Class ID Array                 (CLASS_ID_ARRAY)
     - none or one:     Bbox Sizes                     (BBOX_SIZES)
     - none or one:     Speed Vectors                  (SPEED_VECTORS)
@@ -397,22 +371,24 @@ class OsefKeys(Enum):
     """
     Bbox Sizes
     **Output when**: Tracking is enabled.
-    Contains list of bbox sizes for tracked objects, three per object:
+    **Purpose**: Define bounding boxes around each tracked object.
+    A bounding box is defined by its 3 dimensions, on x, y, z axes, centered on Pose Array.
+    **Format**: Array of bounding box sizes, three single-precision floats per object:
     * x : meters, range [ -inf .. +inf ]
     * y : meters, range [ -inf .. +inf ]
     * z : meters, range [ -inf .. +inf ]
-    The coordinate system is not specified.
     """
     BBOX_SIZES = "bbox_sizes"
 
     """
     Speed Vectors
     **Output when**: Tracking is enabled.
-    Contains list of speed vectors for tracked objects, three per object:
-    * x : meters, range [ -inf .. +inf ]
-    * y : meters, range [ -inf .. +inf ]
-    * z : meters, range [ -inf .. +inf ]
-    The coordinate system is not specified.
+    **Purpose**: Speed vectors, one for each tracked object.
+    Speed vectors are defined on x, y, z axes, centered on Pose Array.
+    **Format**: Array of speed vectors, three single-precision floats per object:
+    * x : meters per second, range [ -inf .. +inf ]
+    * y : meters per second, range [ -inf .. +inf ]
+    * z : meters per second, range [ -inf .. +inf ]
     """
     SPEED_VECTORS = "speed_vectors"
 
@@ -427,20 +403,21 @@ class OsefKeys(Enum):
     absolute referential from the coordinates Xrel in device referential using the vectorial formula:
     Xabs = R * Xrel + T
     **Coordinate Frame**:
-    Absolute/World Frame, witch is:
+    Absolute/World Frame, which is:
     - Single-LiDAR configuration: On-Ground LiDAR Coordinate Frame.
     - Multi-LiDARs configuration: Map Coordinate Frame.
     """
     POSE_ARRAY = "pose_array"
 
     """
-    Object Id
-    **Instead, use**: "Object Id 32 bits" (Type 47)
+    Object ID
+    **Instead, use**: "Object ID 32 bits" (Type 47)
     """
     OBJECT_ID = "object_id"
 
     """
     Cartesian Coordinates 4F
+    **Instead, use**: "Cartesian Coordinates" (Type 6)
     Alternative way to represent coordinates, where a fourth float is added.
     It can be more efficient to construct if an application aligns the points to use SIMD on 128 bits words.
     Contains list of cartesian single-precision float coordinates, four per point:
@@ -568,7 +545,7 @@ class OsefKeys(Enum):
 
     """
     Pose Relative
-    **Output when**: Ego-motion is enabled.
+    **Output when**: Slam is enabled.
     **Purpose**: This pose represents the movement of the device between two scans.
     So the position of the current scan can be computed from the one of the previous scan using the following vectorial
     formula:
@@ -602,7 +579,7 @@ class OsefKeys(Enum):
 
     """
     Ego Motion
-    **Output when**: Ego-motion is enabled.
+    **Output when**: Slam is enabled.
     Contains following sub-TLVs:
     - exactly one:     Pose Relative                  (POSE_RELATIVE)
     - none or one:     Predicted Position             (PREDICTED_POSITION)
@@ -611,7 +588,7 @@ class OsefKeys(Enum):
 
     """
     Predicted Position
-    **Output when**: Ego-motion is enabled.
+    **Output when**: Slam is enabled.
     **Purpose**: Cartesian coordinates of the predicted position in slam.
     The time of prediction is set at startup, and defaults to 1 second.
     **Format**: Contains 3 floats.
@@ -620,9 +597,9 @@ class OsefKeys(Enum):
     _PREDICTED_POSITION = "predicted_position"
 
     """
-    Geographic pose
+    Geographic Pose
     **Deprecated since**: 5.3
-    **Instead, use**: "Geographic pose precise" (Type 57)
+    **Instead, use**: "Geographic Pose Precise" (Type 57)
     **Purpose**: Represents the geographic pose, output from the relocation processing, expressed in decimal degrees
     notation (latitude, longitude & heading).
     **Format**: Concatenation of 3 single precision (32 bits) floats [lat, long, heading].
@@ -633,19 +610,29 @@ class OsefKeys(Enum):
     GEOGRAPHIC_POSE = "geographic_pose"
 
     """
-    Object Id 32 bits
+    Object ID 32 Bits
     **Output when**: Tracking is enabled.
-    **Format**: List of unsigned 32-bits integer.
-    **Purpose**: Contains list of object IDs found by tracking.
-    Each ID represents a distinct tracked object.
-    The affectation of an ID to an object is arbitrary.
-    The special value 0 is used to mean 'no object'.
-    For instance, if the object ID of a point is 0, it means that this point does not belong to any object.
+    **Format**: Array of unsigned 32-bits integers. Each element of the array is an Object ID.
+    **Purpose**: Give a unique identifier (ID) to each detected object.
+    Optionally, this ID can also be used to establish a link between detected objects
+    and the defined Zones, or the points of a Augmented Cloud.
+    When used as leaf of Tracked Objects:
+    - The number of elements of the array is equal to the Number of Objects (type 10).
+    - Each ID represents a distinct detected object.
+    - The affectation of an ID to an object is arbitrary and permanent,
+      it remains the same throughout the tracking phase.
+    When used as leaf of Augmented Cloud:
+    - The number of elements of the array is equal to the Number of Points (type 2).
+    - Each specified ID indicates to witch object the point belongs.
+    - The special value 0 is used to mean 'no object'.
+      For instance, if the object ID of a point is 0,
+      it means that this point does not belong to any object.
+    The Object ID is also used in Zones Objects Binding 32 Bits (type 48), combined with Zone identifier.
     """
     OBJECT_ID_32_BITS = "object_id_32_bits"
 
     """
-    Zones Objects Binding 32 bits
+    Zones Objects Binding 32 Bits
     **Output when**: Tracking is enabled, and at least one zone has been defined.
     **Purpose**: This type is used to know with tracked objects are in which event zones.
     The binary payload is the concatenation of 0 to N couples of:
@@ -656,7 +643,7 @@ class OsefKeys(Enum):
     ZONES_OBJECTS_BINDING_32_BITS = "zones_objects_binding_32_bits"
 
     """
-    Background bits
+    Background Bits
     Contains a padded list of bits, 1 bit per point of the cloud. If the bit is set, the point is a background point.
     The background is defined as the objects which were frequently detected in the past.
     On the contrary the foreground is composed of objects that were not seen before (i.e. they appeared recently and/or
@@ -665,7 +652,7 @@ class OsefKeys(Enum):
     _BACKGROUND_BITS = "background_bits"
 
     """
-    Ground plane bits
+    Ground Plane Bits
     Contains a padded list of bits, 1 bit per point of the cloud. If the bit is set, the point belongs to the ground.
     """
     _GROUND_PLANE_BITS = "ground_plane_bits"
@@ -701,26 +688,7 @@ class OsefKeys(Enum):
 
     """
     LiDAR Model
-    One unsigned 8-bits integer representing a model of LiDAR.
-    * 0: Unknown
-    * 1: Velodyne VLP16
-    * 2: Velodyne VLP32
-    * 3: Velodyne VLS128
-    * 4: Velodyne HDL32
-    * 5: Robosense BPearl v1
-    * 6: Robosense BPearl v2
-    * 7: Robosense RS32
-    * 8: Robosense Helios
-    * 9: Livox Horizon
-    * 10: Livox Avia
-    * 11: Livox Mid70
-    * 12: Ouster
-    * 13: Outsight SA01
-    * 14: Hesai PandarXT32
-    * 15: Hesai PandarQT64
-    * 16: Random (fake LiDAR for testing)
-    * 17: Hesai PandarXT32M2X
-    * 18: Robosense M1
+    One unsigned 8-bits integer representing a model of LiDAR, using enum LIDAR MODEL ID.
     """
     _LIDAR_MODEL = "lidar_model"
 
@@ -759,8 +727,9 @@ class OsefKeys(Enum):
     ZONE_VERTICAL_LIMITS = "zone_vertical_limits"
 
     """
-    Geographic pose precise
-    **Output when**: georeferencing is enabled.
+    Geographic Pose Precise
+    **Output when**: Relocalization in a reference map and georeferencing are enabled.
+    So in processing config: slam.enable set to true, slam.reference_map defined and slam.georeferencing set to true.
     **Purpose**: Represents the geographic pose, output from the relocation processing, expressed in decimal degrees
     notation (latitude, longitude & heading).
     **Format**: Concatenation of 2 double precision (64 bits) and a single precision (32 bits) floats [lat, long,
@@ -772,19 +741,19 @@ class OsefKeys(Enum):
     GEOGRAPHIC_POSE_PRECISE = "geographic_pose_precise"
 
     """
-    Road Markings bits
+    Road Markings Bits
     Contains a padded (up to a byte) list of bits, 1 bit per point of the cloud. If the bit is set, the point belongs
     to a road marking.
     """
     _ROAD_MARKINGS_BITS = "road_markings_bits"
 
     """
-    Filtered Pose
-    **Output when**: Ego-motion is enabled.
-    **Purpose**: Filtered pose of the LiDAR, in order to smooth out the discrepancies.
+    Smoothed Pose
+    **Output when**: SLAM and slam.smooth_output pose are enabled.
+    **Purpose**: Smoothed pose of the LiDAR, in order to smooth out the discrepancies.
     **Format**: Concatenation of 12 floats of 32-bits each, see type Pose for more details.
     """
-    FILTERED_POSE = "filtered_pose"
+    _SMOOTHED_POSE = "smoothed_pose"
 
     """
     Interactive Request
@@ -842,3 +811,60 @@ class OsefKeys(Enum):
     **Format**: The same binary payload as in the request
     """
     _INTERACTIVE_RESPONSE_PINGPONG = "interactive_response_pingpong"
+
+
+class ClassId(IntEnum):
+    """Tracked object class ID"""
+
+    UNKNOWN = 0
+    PERSON = 1
+    LUGGAGE = 2
+    TROLLEY = 3
+    TRUCK = 4
+    BUS = 5
+    CAR = 6
+    VAN = 7
+    TWO_WHEELER = 8
+    MASK = 9
+    NO_MASK = 10
+    LANDMARK = 11
+
+
+class PerceptId(IntEnum):
+    """Percept class ID"""
+
+    DEFAULT = 0
+    ROAD = 1
+    VEGETATION = 2
+    GROUND = 3
+    SIGN = 4
+    BUILDING = 5
+    FLAT_GND = 6
+    UNKNOWN = 7
+    MARKING = 8
+    OBJECT = 9
+    WALL = 10
+
+
+class LidarModelId(IntEnum):
+    """Lidar model ID"""
+
+    UNKNOWN = 0
+    VELODYNE_VLP16 = 1
+    VELODYNE_VLP32 = 2
+    VELODYNE_VLS128 = 3
+    VELODYNE_HDL32 = 4
+    ROBOSENSE_BPEARL_V1 = 5
+    ROBOSENSE_BPEARL_V2 = 6
+    ROBOSENSE_RS32 = 7
+    ROBOSENSE_HELIOS = 8
+    LIVOX_HORIZON = 9
+    LIVOX_AVIA = 10
+    LIVOX_MID70 = 11
+    OUSTER = 12
+    OUTSIGHT_SA01 = 13
+    HESAI_PANDARXT32 = 14
+    HESAI_PANDARQT64 = 15
+    FAKE_LIDAR = 16
+    HESAI_PANDARXT32M2X = 17
+    ROBOSENSE_M1 = 18
