@@ -58,12 +58,8 @@ outsight_types = {
     OsefTypes.CARTESIAN_COORDINATES.value: TypeInfo(
         OsefKeys.CARTESIAN_COORDINATES.value,
         LeafInfo(
-            _unpackers._get_structured_array_unpacker(
-                np.dtype(
-                    ([("x", np.float32), ("y", np.float32), ("z", np.float32)]),
-                )
-            ),
-            _packers._structured_array_packer,
+            _unpackers._get_array_unpacker(np.dtype(np.float32), 3),
+            _packers._array_packer,
         ),
     ),
     OsefTypes._BGR_COLORS.value: TypeInfo(
@@ -171,29 +167,15 @@ outsight_types = {
     OsefTypes.BBOX_SIZES.value: TypeInfo(
         OsefKeys.BBOX_SIZES.value,
         LeafInfo(
-            _unpackers._get_structured_array_unpacker(
-                np.dtype(
-                    (
-                        [
-                            ("bbox_x", np.float32),
-                            ("bbox_y", np.float32),
-                            ("bbox_z", np.float32),
-                        ]
-                    ),
-                ),
-            ),
-            _packers._structured_array_packer,
+            _unpackers._get_array_unpacker(np.dtype(np.float32), 3),
+            _packers._array_packer,
         ),
     ),
     OsefTypes.SPEED_VECTORS.value: TypeInfo(
         OsefKeys.SPEED_VECTORS.value,
         LeafInfo(
-            _unpackers._get_structured_array_unpacker(
-                np.dtype(
-                    ([("Vx", np.float32), ("Vy", np.float32), ("Vz", np.float32)]),
-                ),
-            ),
-            _packers._structured_array_packer,
+            _unpackers._get_array_unpacker(np.dtype(np.float32), 3),
+            _packers._array_packer,
         ),
     ),
     OsefTypes.POSE_ARRAY.value: TypeInfo(
@@ -252,10 +234,8 @@ outsight_types = {
     OsefTypes.ZONE_VERTICES.value: TypeInfo(
         OsefKeys.ZONE_VERTICES.value,
         LeafInfo(
-            _unpackers._get_structured_array_unpacker(
-                np.dtype(([("x", np.float32), ("y", np.float32)])),
-            ),
-            _packers._structured_array_packer,
+            _unpackers._get_array_unpacker(np.dtype(np.float32), 2),
+            _packers._array_packer,
         ),
     ),
     OsefTypes.ZONE_NAME.value: TypeInfo(
@@ -311,12 +291,8 @@ outsight_types = {
     OsefTypes._PREDICTED_POSITION.value: TypeInfo(
         OsefKeys._PREDICTED_POSITION.value,
         LeafInfo(
-            _unpackers._get_structured_array_unpacker(
-                np.dtype(
-                    ([("x", np.float32), ("y", np.float32), ("z", np.float32)]),
-                ),
-            ),
-            _packers._structured_array_packer,
+            _unpackers._get_array_unpacker(np.dtype(np.float32), 3),
+            _packers._array_packer,
         ),
     ),
     OsefTypes.GEOGRAPHIC_POSE.value: TypeInfo(
@@ -417,8 +393,8 @@ outsight_types = {
         OsefKeys._ROAD_MARKINGS_BITS.value,
         LeafInfo(_unpackers._bool_bitfield_unpacker, _packers._bool_bitfield_packer),
     ),
-    OsefTypes.FILTERED_POSE.value: TypeInfo(
-        OsefKeys.FILTERED_POSE.value,
+    OsefTypes._SMOOTHED_POSE.value: TypeInfo(
+        OsefKeys._SMOOTHED_POSE.value,
         LeafInfo(_unpackers._pose_array_unpacker, _packers._pose_array_packer),
     ),
 }
